/* Enhanced Stats grid */
.stats {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(180px, 1fr));
    gap: 1rem;
    margin-bottom: 2rem;
}

.stat-card {
    background: #1e293b;
    padding: 1rem;
    border-radius: 8px;
    border: 1px solid #334155;
    transition: all 0.3s ease;
    display: flex;
    align-items: center;
    gap: 0.75rem;
    position: relative;
    overflow: hidden;
}

.stat-card:hover {
    transform: translateY(-1px);
    box-shadow: 0 4px 15px rgba(0, 0, 0, 0.1);
    border-color: #475569;
}

.stat-card::before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    height: 2px;
    background: linear-gradient(90deg, #0ea5e9, #3b82f6);
}

.stat-card-prompts::before { background: linear-gradient(90deg, #0ea5e9, #06b6d4); }
.stat-card-versions::before { background: linear-gradient(90deg, #8b5cf6, #a855f7); }
.stat-card-cost::before { background: linear-gradient(90deg, #f59e0b, #f97316); }
.stat-card-tokens::before { background: linear-gradient(90deg, #10b981, #059669); }
.stat-card-calls::before { background: linear-gradient(90deg, #ef4444, #dc2626); }

.stat-icon {
    font-size: 1.75rem;
    opacity: 0.9;
}

.stat-content {
    flex: 1;
}

.stat-label {
    color: #94a3b8;
    font-size: 0.75rem;
    margin-bottom: 0.25rem;
    font-weight: 500;
}

.stat-value {
    font-size: 1.5rem;
    font-weight: 700;
    color: #38bdf8;
    line-height: 1;
}

.stat-sublabel {
    color: #64748b;
    font-size: 0.675rem;
    margin-top: 0.125rem;
    font-weight: 500;
}

/* Badges */
.model-badge {
    display: inline-block;
    background: #8b5cf6;
    color: #fff;
    padding: 0.25rem 0.75rem;
    border-radius: 4px;
    font-size: 0.75rem;
    font-weight: 600;
    margin-left: 8px;
}

.diff-badge {
    display: inline-block;
    background: #f59e0b;
    color: #fff;
    padding: 2px 8px;
    border-radius: 12px;
    font-size: 0.75rem;
    font-weight: 600;
    margin-left: 8px;
}

/* Enhanced Buttons */
.btn {
    background: #0ea5e9;
    color: white;
    border: none;
    padding: 0.75rem 1.25rem;
    border-radius: 8px;
    cursor: pointer;
    font-size: 0.875rem;
    font-weight: 600;
    transition: all 0.3s ease;
    display: inline-flex;
    align-items: center;
    gap: 0.5rem;
    text-decoration: none;
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
}

.btn:hover {
    background: #0284c7;
    transform: translateY(-1px);
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15);
}

.btn-secondary {
    background: #475569;
    color: #f1f5f9;
}

.btn-secondary:hover {
    background: #334155;
}

.btn-icon {
    font-size: 1rem;
}

/* Light mode overrides */
body.light-mode .stat-card {
    background: #ffffff;
    border-color: #e2e8f0;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
}

body.light-mode .stat-card:hover {
    box-shadow: 0 4px 15px rgba(0, 0, 0, 0.08);
}

body.light-mode .stat-label { color: #64748b; }
body.light-mode .stat-value { color: #0284c7; }
body.light-mode .stat-sublabel { color: #94a3b8; }

body.light-mode .btn-secondary {
    background: #cbd5e1;
    color: #1e293b;
}

body.light-mode .btn-secondary:hover {
    background: #94a3b8;
}

body.light-mode .search-input,
body.light-mode .sort-select {
    background: #ffffff;
    border-color: #e2e8f0;
    color: #1e293b;
}

body.light-mode .search-input:focus,
body.light-mode .sort-select:focus {
    border-color: #0ea5e9;
}

body.light-mode .section-title,
body.light-mode h1,
body.light-mode h2,
body.light-mode h3 {
    color: #1e293b;
}

body.light-mode .dashboard-header {
    background: linear-gradient(135deg, #ffffff 0%, #f8fafc 100%);
    border-bottom-color: #e2e8f0;
}

body.light-mode .header-title {
    color: #1e293b;
}

body.light-mode .section-description {
    color: #64748b;
}

body.light-mode .header-subtitle {
    color: #64748b;
}
