/* Version list */
.version-list {
    background: #1e293b;
    border-radius: 8px;
    border: 1px solid #334155;
    margin-top: 1rem;
    transition: background 0.3s, border-color 0.3s;
}

.version-item {
    padding: 1rem 1.5rem;
    border-bottom: 1px solid #334155;
}

.version-item:last-child {
    border-bottom: none;
}

.version-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-bottom: 0.5rem;
}

.version-tag {
    background: #0ea5e9;
    color: #fff;
    padding: 0.25rem 0.75rem;
    border-radius: 4px;
    font-size: 0.875rem;
    font-weight: 600;
}

.version-time {
    color: #64748b;
    font-size: 0.875rem;
}

/* Prompt content display */
.prompt-content {
    background: #0f172a;
    padding: 1rem;
    border-radius: 4px;
    font-family: 'Courier New', monospace;
    font-size: 0.875rem;
    white-space: pre-wrap;
    margin-top: 0.5rem;
    line-height: 1.6;
    transition: background 0.3s;
}

.prompt-label {
    color: #38bdf8;
    font-weight: 600;
    margin-bottom: 0.5rem;
}

/* Diff highlighting */
.diff-added {
    background: rgba(34, 197, 94, 0.2);
    color: #86efac;
    padding: 2px 4px;
    border-radius: 3px;
    font-weight: 500;
}

.diff-removed {
    background: rgba(239, 68, 68, 0.2);
    color: #fca5a5;
    padding: 2px 4px;
    border-radius: 3px;
    text-decoration: line-through;
    font-weight: 500;
}

.diff-info {
    color: #94a3b8;
    font-size: 0.875rem;
    margin-top: 0.5rem;
    font-style: italic;
}

/* Delete version button */
.delete-version-btn {
    background: transparent;
    border: none;
    color: #ececec;
    font-size: 1.2rem;
    cursor: pointer;
    margin-left: 0;
    padding: 2px 6px;
    border-radius: 4px;
    transition: background 0.2s, color 0.2s;
    outline: none;
    vertical-align: middle;
}

.delete-version-btn:hover, .delete-version-btn:focus {
    background: rgba(24, 18, 18, 0.12);
    color: #ececec;
}

body.light-mode .delete-version-btn {
    color: #dc2626;
}

body.light-mode .delete-version-btn:hover, body.light-mode .delete-version-btn:focus {
    background: rgba(239, 68, 68, 0.10);
    color: #b91c1c;
}

/* Delete prompt button */
.delete-prompt-btn {
    background: #475569;
    border: none;
    color: #ececec;
    cursor: pointer;
    padding: 0.25rem 0.5rem;
    border-radius: 4px;
    transition: background 0.2s, color 0.2s;
    outline: none;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 0.75rem;
}
.delete-prompt-btn:hover, .delete-prompt-btn:focus {
    background: #334155;
    color: #ececec;
}

body.light-mode .delete-prompt-btn {
    background: #cbd5e1;
    color: #000000;
}
body.light-mode .delete-prompt-btn:hover, body.light-mode .delete-prompt-btn:focus {
    background: #94a3b8;
    color: #000000;
}

body.light-mode .version-list {
    background: #ffffff;
    border-color: #e2e8f0;
}

body.light-mode .version-item {
    border-bottom-color: #e2e8f0;
}

body.light-mode .version-time {
    color: #94a3b8;
}

body.light-mode .prompt-content {
    background: #f8fafc;
    color: #1e293b;
}

body.light-mode .prompt-label {
    color: #0284c7;
}

body.light-mode .diff-added {
    background: rgba(34, 197, 94, 0.15);
    color: #15803d;
}

body.light-mode .diff-removed {
    background: rgba(239, 68, 68, 0.15);
    color: #dc2626;
}

body.light-mode .diff-info {
    color: #64748b;
}
